package de.intevation.flys.artifacts.states;

import java.util.List;

import org.apache.log4j.Logger;

import org.w3c.dom.Element;

import de.intevation.artifacts.Artifact;
import de.intevation.artifacts.CallContext;
import de.intevation.artifacts.CallMeta;

import de.intevation.artifacts.common.utils.XMLUtils;

import de.intevation.flys.model.Gauge;
import de.intevation.flys.model.River;

import de.intevation.flys.artifacts.FLYSArtifact;
import de.intevation.flys.utils.FLYSUtils;


/**
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class ReferenceGaugeState extends DefaultState {

    private static final Logger logger =
        Logger.getLogger(ReferenceGaugeState.class);


    public static final String DATA_NAME = "reference_gauge";


    @Override
    protected Element[] createItems(
        XMLUtils.ElementCreator cr,
        Artifact    artifact,
        String      name,
        CallContext context)
    {
        CallMeta  meta = context.getMeta();

        River       river   = FLYSUtils.getRiver((FLYSArtifact) artifact);
        List<Gauge> gauges  = river.getGauges();

        int num = gauges != null ? gauges.size() : 0;

        Element[] opts = new Element[num];

        for (int i = 0; i < num; i++ ) {
            Gauge g = gauges.get(i);

            String gaugeName      = g.getName();
            long   officialNumber = g.getOfficialNumber();

            opts[i] = createItem(
                cr, new String[] { gaugeName, String.valueOf(officialNumber) });
        }

        return opts;
    }


    @Override
    protected String getLabelFor(
        CallContext cc,
        String      name,
        String      value,
        String      type
    ) {
        if (name.equals(DATA_NAME)) {
            try {
                long  number = Long.valueOf(value);
                Gauge gauge  = Gauge.getGaugeByOfficialNumber(number);

                if (gauge != null) {
                    return gauge.getName();
                }
            }
            catch (NumberFormatException nfe) {
                // do nothing
            }
        }

        return super.getLabelFor(cc, name, value, type);
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf-8 :
